@@ -44,7 +44,7 @@ class User(OdnoklassnikiPKModel):
         verbose_name = _('Odnoklassniki user')
         verbose_name_plural = _('Odnoklassniki users')
 
-#    resolve_screen_name_type = 'user'
+    resolve_screen_name_type = 'PROFILE'
     methods_namespace = 'users'
     remote_pk_field = 'uid'
     slug_prefix = 'profile'
@@ -120,3 +120,6 @@ class User(OdnoklassnikiPKModel):
 
     def __unicode__(self):
         return self.name
+
+    def get_gender(self):
+        return dict(USER_SEX_CHOICES).get(self.gender)
\ No newline at end of file
